@@ -587,8 +587,8 @@ ryuhei@secondbrain.co.jp
           echo '                <td><a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, tep_get_path($cInfo_array[$i]['categories_id'])) . '"><b><font size="+1">' . $cInfo_array[$i]['categories_name'] . "</font></b></a></td>\n";
           echo '                <td>' . "\n";
           echo '                  <table border="0" width="100%" cellspacing="0" cellpadding="2">' . "\n";
-          echo '                    <tr><td class="dataTableContent">' . TABLE_HEADING_SUBCATEGORIES . '</td><td class="dataTableContent">' . $cInfo_array[$i]['childs_count'] . '</td><td><a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, tep_get_path($cInfo_array[$i]['categories_id'])) . '">' . TEXT_GO_TO_LIST . "</a></td></tr>\n";
-          echo '                    <tr><td class="dataTableContent">' . TABLE_HEADING_PRODUCTS . '</td><td class="dataTableContent">' . $cInfo_array[$i]['products_conut'] .'</td><td>' . (file_exists(FILENAME_PRODUCTS_EDIT) ? '<a href="' . tep_href_link(FILENAME_PRODUCTS_EDIT, 'action=search&subject=categories_id&value=' . $cInfo_array[$i]['categories_id']) . '">' . TEXT_GO_TO_LIST . '</a>' : "&nbsp;") .  "</td></tr>\n";
+          echo '                    <tr><td class="dataTableContent">' . TABLE_HEADING_SUBCATEGORIES . '</td><td align="right" class="dataTableContent">' . $cInfo_array[$i]['childs_count'] . '</td><td><a href="' . tep_href_link(FILENAME_CATEGORIES_EDIT, tep_get_path($cInfo_array[$i]['categories_id'])) . '">' . TEXT_GO_TO_LIST . "</a></td></tr>\n";
+          echo '                    <tr><td class="dataTableContent">' . TABLE_HEADING_PRODUCTS . '</td><td align="right" class="dataTableContent">' . $cInfo_array[$i]['products_count'] .'</td><td>' . (file_exists(FILENAME_PRODUCTS_EDIT) ? '<a href="' . tep_href_link(FILENAME_PRODUCTS_EDIT, 'action=search&subject=categories_id&value=' . $cInfo_array[$i]['categories_id']) . '">' . TEXT_GO_TO_LIST . '</a>' : "&nbsp;") .  "</td></tr>\n";
           echo '                  </table>' . "\n";
           echo "                </td>\n";
           echo '                <td>' . "\n";
