@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: file_manager.php,v 1.1.1.1 2005/06/30 05:03:56 ryu Exp $
+  $Id: file_manager.php,v 1.2 2006/01/29 14:49:22 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -77,9 +77,12 @@
         tep_redirect(tep_href_link(FILENAME_FILE_MANAGER));
         break;
       case 'download':
-        header('Content-type: application/x-octet-stream');
-        header('Content-disposition: attachment; filename=' . urldecode($HTTP_GET_VARS['filename']));
-        readfile($current_path . '/' . urldecode($HTTP_GET_VARS['filename']));
+        $filename = $HTTP_GET_VARS['filename'];
+        if ((substr($filename,0,1) != '/') && !strstr($filename,'..')) {
+          header('Content-type: application/x-octet-stream');
+          header('Content-disposition: attachment; filename=' . urldecode($filename));
+          readfile($current_path . '/' . urldecode($filename));
+        }
         exit;
         break;
       case 'upload':
