@@ -49,25 +49,30 @@ ryuhei@secondbrain.co.jp
             $geta_themes['geta_themes_title'] = $HTTP_POST_VARS['geta_themes_title'];
             $geta_themes['geta_themes_description'] = $HTTP_POST_VARS['geta_themes_description'];
             $geta_themes['geta_themes_keywords'] = $HTTP_POST_VARS['geta_themes_keywords'];
-            $geta_themes_image1 = $HTTP_POST_VARS['geta_themes_image1_path'];
-            $geta_themes_image2 = $HTTP_POST_VARS['geta_themes_image2_path'];
-            $geta_themes_image3 = $HTTP_POST_VARS['geta_themes_image3_path'];
-            $geta_themes_image4 = $HTTP_POST_VARS['geta_themes_image4_path'];
-            $geta_themes_image5 = $HTTP_POST_VARS['geta_themes_image5_path'];
+            $geta_themes['geta_themes_image1'] = $HTTP_POST_VARS['geta_themes_image1_path'];
+            $geta_themes['geta_themes_image2'] = $HTTP_POST_VARS['geta_themes_image2_path'];
+            $geta_themes['geta_themes_image3'] = $HTTP_POST_VARS['geta_themes_image3_path'];
+            $geta_themes['geta_themes_image4'] = $HTTP_POST_VARS['geta_themes_image4_path'];
+            $geta_themes['geta_themes_image5'] = $HTTP_POST_VARS['geta_themes_image5_path'];
             $gtInfo = new objectInfo($geta_themes);
             $HTTP_GET_VARS['action'] = 'new_theme';
           } else {
-            $geta_themes_title = $HTTP_POST_VARS['geta_themes_title'];
-            $geta_themes_description = $HTTP_POST_VARS['geta_themes_description'];
-            $geta_themes_keywords = $HTTP_POST_VARS['geta_themes_keywords'];
-            $sql_data_array = array('geta_themes_title' => tep_db_input($geta_themes_title),
-                                        'geta_themes_description' => tep_db_input($geta_themes_description),
-                                        'geta_themes_keywords' => tep_db_input($geta_themes_keywords),
-                                        'geta_themes_image1' => tep_db_input($geta_themes_image1),
-                                        'geta_themes_image2' => tep_db_input($geta_themes_image2),
-                                        'geta_themes_image3' => tep_db_input($geta_themes_image3),
-                                        'geta_themes_image4' => tep_db_input($geta_themes_image4),
-                                        'geta_themes_image5' => tep_db_input($geta_themes_image5),
+            $geta_themes_title = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_title']);
+            $geta_themes_description = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_description']);
+            $geta_themes_keywords = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_keywords']);
+            $geta_themes_image1 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image1_path']);
+            $geta_themes_image2 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image2_path']);
+            $geta_themes_image3 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image3_path']);
+            $geta_themes_image4 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image4_path']);
+            $geta_themes_image5 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image5_path']);
+            $sql_data_array = array('geta_themes_title' => $geta_themes_title,
+                                        'geta_themes_description' => $geta_themes_description,
+                                        'geta_themes_keywords' => $geta_themes_keywords,
+                                        'geta_themes_image1' => $geta_themes_image1,
+                                        'geta_themes_image2' => $geta_themes_image2,
+                                        'geta_themes_image3' => $geta_themes_image3,
+                                        'geta_themes_image4' => $geta_themes_image4,
+                                        'geta_themes_image5' => $geta_themes_image5,
                                         'date_added' =>  'now()');
             tep_db_perform(TABLE_GETA_THEMES, $sql_data_array);
             $messageStack->add_session(SUCCESS_GETA_THEME_INSERT_COMPLETE, 'success');
@@ -112,23 +117,23 @@ ryuhei@secondbrain.co.jp
             $gtInfo = new objectInfo($geta_themes);
             $HTTP_GET_VARS['action'] = 'edit_theme';
           } else {
-            $geta_themes_id = $HTTP_POST_VARS['geta_themes_id'];
-            $geta_themes_title = $HTTP_POST_VARS['geta_themes_title'];
-            $geta_themes_description = $HTTP_POST_VARS['geta_themes_description'];
-            $geta_themes_keywords = $HTTP_POST_VARS['geta_themes_keywords'];
-            $geta_themes_image1 = $HTTP_POST_VARS['geta_themes_image1_path'];
-            $geta_themes_image2 = $HTTP_POST_VARS['geta_themes_image2_path'];
-            $geta_themes_image3 = $HTTP_POST_VARS['geta_themes_image3_path'];
-            $geta_themes_image4 = $HTTP_POST_VARS['geta_themes_image4_path'];
-            $geta_themes_image5 = $HTTP_POST_VARS['geta_themes_image5_path'];
-            $sql_data_array = array('geta_themes_title' => tep_db_input($geta_themes_title),
-                                        'geta_themes_description' => tep_db_input($geta_themes_description),
-                                        'geta_themes_keywords' => tep_db_input($geta_themes_keywords),
-                                        'geta_themes_image1' => tep_db_input($geta_themes_image1),
-                                        'geta_themes_image2' => tep_db_input($geta_themes_image2),
-                                        'geta_themes_image3' => tep_db_input($geta_themes_image3),
-                                        'geta_themes_image4' => tep_db_input($geta_themes_image4),
-                                        'geta_themes_image5' => tep_db_input($geta_themes_image5),
+            $geta_themes_id = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_id']);
+            $geta_themes_title = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_title']);
+            $geta_themes_description = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_description']);
+            $geta_themes_keywords = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_keywords']);
+            $geta_themes_image1 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image1_path']);
+            $geta_themes_image2 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image2_path']);
+            $geta_themes_image3 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image3_path']);
+            $geta_themes_image4 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image4_path']);
+            $geta_themes_image5 = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_image5_path']);
+            $sql_data_array = array('geta_themes_title' => $geta_themes_title,
+                                        'geta_themes_description' => $geta_themes_description,
+                                        'geta_themes_keywords' => $geta_themes_keywords,
+                                        'geta_themes_image1' => $geta_themes_image1,
+                                        'geta_themes_image2' => $geta_themes_image2,
+                                        'geta_themes_image3' => $geta_themes_image3,
+                                        'geta_themes_image4' => $geta_themes_image4,
+                                        'geta_themes_image5' => $geta_themes_image5,
                                         'last_modified' =>  'now()');
             tep_db_perform(TABLE_GETA_THEMES, $sql_data_array, 'update', 'geta_themes_id = \'' . tep_db_input($geta_themes_id) . '\'');
             $messageStack->add_session(SUCCESS_GETA_THEME_UPDATE_COMPLETE, 'success');
@@ -138,7 +143,7 @@ ryuhei@secondbrain.co.jp
         break;
       case 'delete':
         // ơޤκ
-        $geta_themes_id = $HTTP_POST_VARS['geta_themes_id'];
+        $geta_themes_id = tep_db_prepare_input($HTTP_POST_VARS['geta_themes_id']);
         tep_db_query("delete from " . TABLE_GETA_THEMES . " where geta_themes_id = '" . tep_db_input($geta_themes_id) . "'");
         $messageStack->add_session(SUCCESS_GETA_THEME_DELETE_COMPLETE, 'success');
         tep_redirect(tep_href_link(FILENAME_GETA_THEMES));
