@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: html_graphs.php,v 1.1.1.1 2005/06/30 05:04:07 ryu Exp $
+  $Id: html_graphs.php,v 1.2 2007/04/16 05:39:33 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -365,7 +365,7 @@
 ////
 // draws a double vertical bar graph for the banner views vs clicks statistics
   function tep_banner_graph_infoBox($banner_id, $days) {
-    $banner_stats_query = tep_db_query("select dayofmonth(banners_history_date) as name, banners_shown as value, banners_clicked as dvalue from " . TABLE_BANNERS_HISTORY . " where banners_id = '" . $banner_id . "' and to_days(now()) - to_days(banners_history_date) < " . $days . " order by banners_history_date");
+    $banner_stats_query = tep_db_query("select dayofmonth(banners_history_date) as name, banners_shown as value, banners_clicked as dvalue from " . TABLE_BANNERS_HISTORY . " where banners_id = '" . (int)$banner_id . "' and to_days(now()) - to_days(banners_history_date) < " . tep_db_input($days) . " order by banners_history_date");
     while ($banner_stats = tep_db_fetch_array($banner_stats_query)) {
       $names[] = $banner_stats['name'];
       $values[] = $banner_stats['value'];
@@ -410,7 +410,7 @@
   function tep_banner_graph_yearly($banner_id) {
     global $banner, $HTTP_GET_VARS;
 
-    $banner_stats_query = tep_db_query("select year(banners_history_date) as year, sum(banners_shown) as value, sum(banners_clicked) as dvalue from " . TABLE_BANNERS_HISTORY . " where banners_id = '" . $banner_id . "' group by year(banners_history_date)");
+    $banner_stats_query = tep_db_query("select year(banners_history_date) as year, sum(banners_shown) as value, sum(banners_clicked) as dvalue from " . TABLE_BANNERS_HISTORY . " where banners_id = '" . (int)$banner_id . "' group by year(banners_history_date)");
     while ($banner_stats = tep_db_fetch_array($banner_stats_query)) {
       $names[] = $banner_stats['year'];
       $values[] = (($banner_stats['value']) ? $banner_stats['value'] : '0');
@@ -464,7 +464,7 @@
       $dvalues[] = '0';
     }
 
-    $banner_stats_query = tep_db_query("select month(banners_history_date) as banner_month, sum(banners_shown) as value, sum(banners_clicked) as dvalue from " . TABLE_BANNERS_HISTORY . " where banners_id = '" . $banner_id . "' and year(banners_history_date) = '" . $year . "' group by month(banners_history_date)");
+    $banner_stats_query = tep_db_query("select month(banners_history_date) as banner_month, sum(banners_shown) as value, sum(banners_clicked) as dvalue from " . TABLE_BANNERS_HISTORY . " where banners_id = '" . (int)$banner_id . "' and year(banners_history_date) = '" . tep_db_input($year) . "' group by month(banners_history_date)");
     while ($banner_stats = tep_db_fetch_array($banner_stats_query)) {
       $names[($banner_stats['banner_month']-1)] = strftime('%b', mktime(0,0,0,$banner_stats['banner_month']));
       $values[($banner_stats['banner_month']-1)] = (($banner_stats['value']) ? $banner_stats['value'] : '0');
@@ -521,7 +521,7 @@
       $dvalues[] = '0';
     }
 
-    $banner_stats_query = tep_db_query("select dayofmonth(banners_history_date) as banner_day, banners_shown as value, banners_clicked as dvalue from " . TABLE_BANNERS_HISTORY . " where banners_id = '" . $banner_id . "' and month(banners_history_date) = '" . $month . "' and year(banners_history_date) = '" . $year . "'");
+    $banner_stats_query = tep_db_query("select dayofmonth(banners_history_date) as banner_day, banners_shown as value, banners_clicked as dvalue from " . TABLE_BANNERS_HISTORY . " where banners_id = '" . (int)$banner_id . "' and month(banners_history_date) = '" . tep_db_input($month) . "' and year(banners_history_date) = '" . tep_db_input($year) . "'");
     while ($banner_stats = tep_db_fetch_array($banner_stats_query)) {
       $names[($banner_stats['banner_day']-1)] = $banner_stats['banner_day'];
       $values[($banner_stats['banner_day']-1)] = (($banner_stats['value']) ? $banner_stats['value'] : '0');
