@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: manufacturers.php,v 1.1.1.1 2005/06/30 05:03:59 ryu Exp $
+  $Id: manufacturers.php,v 1.2 2007/04/16 05:39:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -46,14 +46,14 @@
           } else {
             @mkdir($image_directory, 0777);
             if (is_dir($image_directory)) {
-              tep_db_query("update " . TABLE_MANUFACTURERS . " set manufacturers_image = '" . DIR_WS_MANUFACTURERS_IMAGES . $manufacturers_image['name'] . "' where manufacturers_id = '" . tep_db_input($manufacturers_id) . "'");
+              tep_db_query("update " . TABLE_MANUFACTURERS . " set manufacturers_image = '" . DIR_WS_MANUFACTURERS_IMAGES . tep_db_input($manufacturers_image['name']) . "' where manufacturers_id = '" . tep_db_input($manufacturers_id) . "'");
               tep_copy_uploaded_file($manufacturers_image, $image_directory);
             } else {
               $messageStack->add_session(sprintf(ERROR_DIRECTORY_DOES_NOT_EXIST, $image_directory), 'error');
             }
           }
         } else {
-          tep_db_query("update " . TABLE_MANUFACTURERS . " set manufacturers_image = '" . DIR_WS_MANUFACTURERS_IMAGES . $manufacturers_image['name'] . "' where manufacturers_id = '" . tep_db_input($manufacturers_id) . "'");
+          tep_db_query("update " . TABLE_MANUFACTURERS . " set manufacturers_image = '" . DIR_WS_MANUFACTURERS_IMAGES . tep_db_input($manufacturers_image['name']) . "' where manufacturers_id = '" . tep_db_input($manufacturers_id) . "'");
           tep_copy_uploaded_file($manufacturers_image, $image_directory);
         }
       }
