@@ -463,15 +463,15 @@ ryuhei@secondbrain.co.jp
               tep_db_query("update " . TABLE_PRODUCTS . " set products_model = '" . $products_id . "' where products_id = '" . $products_id . "'");
             }
             // products_to_categoriesơ֥ɲ
-            tep_db_query("insert into " . TABLE_PRODUCTS_TO_CATEGORIES . " (products_id, categories_id) values ('" . $products_id . "', '" . $categories_id . "')");
+            tep_db_query("insert into " . TABLE_PRODUCTS_TO_CATEGORIES . " (products_id, categories_id) values ('" . $products_id . "', '" . tep_db_input($categories_id) . "')");
           } elseif ($HTTP_GET_VARS['action'] == 'update_product') {
             $update_sql_data = array('products_last_modified' => 'now()');
             $sql_data_array = tep_array_merge($sql_data_array, $update_sql_data);
             tep_db_perform(TABLE_PRODUCTS, $sql_data_array, 'update', 'products_id = \'' . $products_id . '\'');
             if ($previous_categories_id != $categories_id) {
               // ƥ꡼Ѥä硢products_to_categoriesơ֥κɲäԤʤ
-              tep_db_query("delete from " . TABLE_PRODUCTS_TO_CATEGORIES . " where products_id = '" . $products_id . "' and categories_id='" . $previous_categories_id . "'");
-              tep_db_query("insert into " . TABLE_PRODUCTS_TO_CATEGORIES . " (products_id, categories_id) values ('" . $products_id . "', '" . $categories_id . "')");
+              tep_db_query("delete from " . TABLE_PRODUCTS_TO_CATEGORIES . " where products_id = '" . $products_id . "' and categories_id='" . tep_db_input($previous_categories_id) . "'");
+              tep_db_query("insert into " . TABLE_PRODUCTS_TO_CATEGORIES . " (products_id, categories_id) values ('" . $products_id . "', '" . tep_db_input($categories_id) . "')");
             }
           }
           // products_descriptionơ֥ι
@@ -968,7 +968,7 @@ ryuhei@secondbrain.co.jp
 <?php
       }
       if (KN_CFG_USE_MANUFACTURERS != '') {
-        $manufacturers_query = tep_db_query("select manufacturers_name from " . TABLE_MANUFACTURERS . " where manufacturers_id = '" . $HTTP_POST_VARS['manufacturers_id'] . "'");
+        $manufacturers_query = tep_db_query("select manufacturers_name from " . TABLE_MANUFACTURERS . " where manufacturers_id = '" . (int)$HTTP_POST_VARS['manufacturers_id'] . "'");
         $manufacturers = tep_db_fetch_array($manufacturers_query);
 ?>
           <tr>
