@@ -185,7 +185,7 @@ ryuhei@secondbrain.co.jp
         // åץɥƥåףåץɥǡƳǧ
         // åѥƥ꡼ꥹȺ
         $categories_id_array = array();
-        $categories_query = tep_db_query("select c.categories_id, cd.categories_name from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.categories_id = cd.categories_id and cd.language_id='" . tep_db_prepare_input($HTTP_POST_VARS['language_id']) ."'");
+        $categories_query = tep_db_query("select c.categories_id, cd.categories_name from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.categories_id = cd.categories_id and cd.language_id='" . tep_db_input($HTTP_POST_VARS['language_id']) ."'");
         while ($categories = tep_db_fetch_array($categories_query)) {
           $categories_id_array[$categories['categories_id']] = $categories['categories_name'];
         }
@@ -451,7 +451,7 @@ ryuhei@secondbrain.co.jp
             }
             if (($ini_data['upfile_mode'] == 'yes_ignore') || ($ini_data['upfile_mode'] == 'yes_replace')) {
               // ޤƱΥǡʤ
-              if (tep_db_num_rows(tep_db_query("select * from " . TABLE_PRODUCTS . " where products_id = '" . $specified_id . "'")) == 0) {
+              if (tep_db_num_rows(tep_db_query("select * from " . TABLE_PRODUCTS . " where products_id = '" . tep_db_input($specified_id) . "'")) == 0) {
                 // yes_ignoreyes_replaceȤinsert
                 // productsơ֥ؤϿ
                 $insert_p_data = array('products_id' => $specified_id,
@@ -673,7 +673,7 @@ ryuhei@secondbrain.co.jp
                   $cname_flg = true;
                   // ƥ꡼̾ѥƥ꡼ꥹȺ
                   $categories_id_array = array();
-                  $categories_query = tep_db_query("select c.categories_id, cd.categories_name from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.categories_id = cd.categories_id and cd.language_id='" . tep_db_prepare_input($HTTP_POST_VARS['language_id']) ."'");
+                  $categories_query = tep_db_query("select c.categories_id, cd.categories_name from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.categories_id = cd.categories_id and cd.language_id='" . tep_db_input($HTTP_POST_VARS['language_id']) ."'");
                   while ($categories = tep_db_fetch_array($categories_query)) {
                     $categories_id_array[$categories['categories_id']] = $categories['categories_name'];
                   }
@@ -708,7 +708,7 @@ ryuhei@secondbrain.co.jp
         }
         fclose($download_cfg_file);
        
-        $download_sql = "select " . $select_column_list . " from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd left join " . TABLE_PRODUCTS_TO_CATEGORIES . " p2c on p.products_id = p2c.products_id where pd.products_id = p.products_id and pd.language_id = '" . tep_db_prepare_input($HTTP_POST_VARS['language_id']) . "'";
+        $download_sql = "select " . $select_column_list . " from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd left join " . TABLE_PRODUCTS_TO_CATEGORIES . " p2c on p.products_id = p2c.products_id where pd.products_id = p.products_id and pd.language_id = '" . tep_db_input($HTTP_POST_VARS['language_id']) . "'";
         $download_query = tep_db_query($download_sql);
         while($download = tep_db_fetch_array($download_query)) {
         	 $csv_rec = '';
@@ -1426,7 +1426,7 @@ switch ($HTTP_GET_VARS['action']) {
 <?php
         // оݾʤΰɽ
         for ($i = 0, $n = sizeof($delete_products); $i < $n; $i++) {
-          $categories_query = tep_db_query("select categories_name from " . TABLE_CATEGORIES_DESCRIPTION . " where categories_id = '" . $delete_products[$i]['categories_id'] . "' and language_id = '" . $languages_id . "'");
+          $categories_query = tep_db_query("select categories_name from " . TABLE_CATEGORIES_DESCRIPTION . " where categories_id = '" . (int)$delete_products[$i]['categories_id'] . "' and language_id = '" . $languages_id . "'");
           $categories = tep_db_fetch_array($categories_query);
           echo '              <tr class="dataTableRow">' . "\n";
           echo '                <td class="dataTableContent">' . $categories['categories_name'] . "</td>\n";
