@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: reviews.php,v 1.2 2005/07/25 09:16:08 ryu Exp $
+  $Id: reviews.php,v 1.3 2007/04/16 05:39:23 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -26,9 +26,9 @@
           $customers_name = tep_db_prepare_input($HTTP_POST_VARS['customers_name']);
           $reviews_rating = tep_db_prepare_input($HTTP_POST_VARS['reviews_rating']);
           $reviews_text = tep_db_prepare_input($HTTP_POST_VARS['reviews_text']);
-          tep_db_query("insert into " . TABLE_REVIEWS . " (products_id, customers_name, reviews_rating, date_added) values ('" . $products_id . "', '" . $customers_name . "', '" . $reviews_rating . "', now())");
+          tep_db_query("insert into " . TABLE_REVIEWS . " (products_id, customers_name, reviews_rating, date_added) values ('" . (int)$products_id . "', '" . tep_db_input($customers_name) . "', '" . (int)$reviews_rating . "', now())");
           $reviews_id = tep_db_insert_id();
-          tep_db_query("insert into " . TABLE_REVIEWS_DESCRIPTION . " (reviews_id, languages_id, reviews_text) values ('" . $reviews_id . "', '" . $languages_id . "', '" . $reviews_text . "')");
+          tep_db_query("insert into " . TABLE_REVIEWS_DESCRIPTION . " (reviews_id, languages_id, reviews_text) values ('" . $reviews_id . "', '" . $languages_id . "', '" . tep_db_input($reviews_text) . "')");
           tep_redirect(tep_href_link(FILENAME_REVIEWS, 'page=' . $HTTP_GET_VARS['page'] . '&rID=' . $reviews_id));
         }
         break;
@@ -144,7 +144,7 @@
     if ($HTTP_POST_VARS) {
       $rInfo = new objectInfo($HTTP_POST_VARS);
     } else {
-      $reviews_query = tep_db_query("select r.reviews_id, r.products_id, r.customers_name, r.date_added, r.last_modified, r.reviews_read, rd.reviews_text, r.reviews_rating from " . TABLE_REVIEWS . " r, " . TABLE_REVIEWS_DESCRIPTION . " rd where r.reviews_id = '" . $HTTP_GET_VARS['rID'] . "' and r.reviews_id = rd.reviews_id");
+      $reviews_query = tep_db_query("select r.reviews_id, r.products_id, r.customers_name, r.date_added, r.last_modified, r.reviews_read, rd.reviews_text, r.reviews_rating from " . TABLE_REVIEWS . " r, " . TABLE_REVIEWS_DESCRIPTION . " rd where r.reviews_id = '" . (int)$HTTP_GET_VARS['rID'] . "' and r.reviews_id = rd.reviews_id");
       $reviews = tep_db_fetch_array($reviews_query);
       $products_query = tep_db_query("select products_image from " . TABLE_PRODUCTS . " where products_id = '" . $reviews['products_id'] . "'");
       $products = tep_db_fetch_array($products_query);
