@@ -15,10 +15,47 @@ ryuhei@secondbrain.co.jp
 
   if ($HTTP_GET_VARS['action']) {
     switch ($HTTP_GET_VARS['action']) {
+      case 'insert':
+        // ʸ̤Ͽ
+        if (($HTTP_POST_VARS['edit_x']) || ($HTTP_POST_VARS['edit_y'])) {
+          // ץӥ塼̤ܥ򲡤줿Ȥ
+          $shop_info = array();
+          $shop_info['shop_info_title'] = $HTTP_POST_VARS['shop_info_title'];
+          $shop_info['shop_info_value'] = $HTTP_POST_VARS['shop_info_value'];
+          $shop_info['shop_info_value2'] = $HTTP_POST_VARS['shop_info_value2'];
+          $shop_info['shop_info_note'] = $HTTP_POST_VARS['shop_info_note'];
+          $shop_info['allow_edit_title'] = $HTTP_POST_VARS['allow_edit_title'];
+          $shop_info['allow_edit_value2'] = $HTTP_POST_VARS['allow_edit_value2'];
+          $shop_info['allow_tags'] = $HTTP_POST_VARS['allow_tags'];
+          $shop_info['last_modified'] = '';
+          $siInfo = new objectInfo($shop_info);
+          $HTTP_GET_VARS['action'] = 'add_value';
+        } else {
+          $shop_info_title = tep_db_prepare_input($HTTP_POST_VARS['shop_info_title']);
+          $shop_info_value = tep_db_prepare_input($HTTP_POST_VARS['shop_info_value']);
+          $shop_info_value2 = tep_db_prepare_input($HTTP_POST_VARS['shop_info_value2']);
+          $shop_info_note = tep_db_prepare_input($HTTP_POST_VARS['shop_info_note']);
+          $allow_edit_title = tep_db_prepare_input($HTTP_POST_VARS['allow_edit_title']);
+          $allow_edit_value2 = tep_db_prepare_input($HTTP_POST_VARS['allow_edit_value2']);
+          $allow_tags = tep_db_prepare_input($HTTP_POST_VARS['allow_tags']);
+          $sql_data_array = array('shop_info_key' => 'SHOP_INFO_OPTIONAL',
+                                      'shop_info_title' => $shop_info_title,
+                                      'shop_info_value' => $shop_info_value,
+                                      'shop_info_value2' => $shop_info_value2,
+                                      'shop_info_note' => $shop_info_note,
+                                      'allow_edit_title' => $allow_edit_title,
+                                      'allow_edit_value2' => $allow_edit_value2,
+                                      'allow_tags' => $allow_tags,
+                                      'shop_info_type' => 1,
+                                      'date_added' =>  'now()');
+          tep_db_perform(TABLE_SHOP_INFO, $sql_data_array);
+          tep_redirect(tep_href_link(FILENAME_SHOP_INFO));
+        }
+        break;
       case 'update':
         // ʸ̤ι
         if (($HTTP_POST_VARS['edit_x']) || ($HTTP_POST_VARS['edit_y'])) {
-        	 // ץӥ塼̤ܥ򲡤줿Ȥ
+          // ץӥ塼̤ܥ򲡤줿Ȥ
           $siID = $HTTP_POST_VARS['shop_info_id'];
           $shop_info = array();
           $shop_info['shop_info_title'] = $HTTP_POST_VARS['shop_info_title'];
@@ -46,16 +83,32 @@ ryuhei@secondbrain.co.jp
           tep_redirect(tep_href_link(FILENAME_SHOP_INFO));
         }
         break;
+      case 'add_value':
+        // ʸ̤Ͽ
+        $page_title = TEXT_ADD_SHOP_INFO;
+        $siID = '';
+        $shop_info = array();
+        $shop_info['shop_info_title'] = '';
+        $shop_info['shop_info_value'] = '';
+        $shop_info['shop_info_value2'] = '';
+        $shop_info['shop_info_note'] = TEXT_OPTIONAL_SHOP_INFO_NOTE;
+        $shop_info['allow_edit_title'] = 1;
+        $shop_info['allow_edit_value2'] = '';
+        $shop_info['allow_tags'] = 0;
+        $shop_info['last_modified'] = '';
+        $siInfo = new objectInfo($shop_info);
+        break;
       case 'edit_value':
         // ʸ̤Խ
+        $page_title = TEXT_EDIT_SHOP_INFO;
         $siID = ((get_magic_quotes_gpc()) ? stripslashes($HTTP_GET_VARS['siID']) : $HTTP_GET_VARS['siID']);
-        $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, shop_info_value2, shop_info_note, allow_edit_title, allow_edit_value2, allow_tags, last_modified from " . TABLE_SHOP_INFO . " where shop_info_id = '" . tep_db_input($siID) . "'");
+        $shop_info_query = tep_db_query("select shop_info_title, shop_info_key, shop_info_value, shop_info_value2, shop_info_note, allow_edit_title, allow_edit_value2, allow_tags, last_modified from " . TABLE_SHOP_INFO . " where shop_info_id = '" . tep_db_input($siID) . "'");
         $shop_info = tep_db_fetch_array($shop_info_query);
         $siInfo = new objectInfo($shop_info);
         break;
       case 'confirm':
         // ԽƤγǧ
-        $siID = $HTTP_POST_VARS['siID'];
+        $siID = $HTTP_POST_VARS['shop_info_id'];
         $shop_info = array();
         $shop_info['shop_info_title'] = $HTTP_POST_VARS['shop_info_title'];
         $shop_info['shop_info_value'] = $HTTP_POST_VARS['shop_info_value'];
@@ -71,10 +124,26 @@ ryuhei@secondbrain.co.jp
         $shop_info['last_modified'] = $HTTP_POST_VARS['last_modified'];
         $siInfo = new objectInfo($shop_info);
         break;
+      case 'delete_confirm':
+        // γǧ
+        $siID = $HTTP_GET_VARS['shop_info_id'];
+        $shop_info_query = tep_db_query("select shop_info_title, shop_info_value, shop_info_value2, shop_info_note, allow_edit_title, allow_edit_value2, allow_tags, last_modified from " . TABLE_SHOP_INFO . " where shop_info_id = '" . tep_db_input($siID) . "'");
+        $shop_info = tep_db_fetch_array($shop_info_query);
+        $siInfo = new objectInfo($shop_info);
+        break;
+      case 'delete':
+        // γǧ
+        $siID = $HTTP_POST_VARS['shop_info_id'];
+        tep_db_query("delete from " . TABLE_SHOP_INFO . " where shop_info_id = '" . tep_db_input($siID) . "'");
+        tep_redirect(tep_href_link(FILENAME_SHOP_INFO));
+        break;
     }
   } else {
     // 
-    $shop_info_query = tep_db_query("select shop_info_id, shop_info_title, shop_info_note from " . TABLE_SHOP_INFO . " where shop_info_type < 2 order by shop_info_id");
+    // ߤΤΤ餻
+    $shop_info_query = tep_db_query("select shop_info_id, shop_info_title, shop_info_note from " . TABLE_SHOP_INFO . " where shop_info_type < 2 and shop_info_key <> 'SHOP_INFO_OPTIONAL' order by shop_info_id");
+    // ǤդΤΤ餻
+    $shop_info2_query = tep_db_query("select shop_info_id, shop_info_title, shop_info_note from " . TABLE_SHOP_INFO . " where shop_info_key = 'SHOP_INFO_OPTIONAL' order by shop_info_id");
   }
 ?>
 <!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
@@ -102,6 +171,7 @@ ryuhei@secondbrain.co.jp
 <?php
   if ($HTTP_GET_VARS['action']) {
     switch ($HTTP_GET_VARS['action']) {
+      case 'add_value':
       case 'edit_value':
       // Խ
 ?>
@@ -109,7 +179,7 @@ ryuhei@secondbrain.co.jp
       <tr>
         <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
           <tr>
-            <td class="pageHeading"><?php echo TEXT_EDIT_SHOP_INFO; ?></td>
+            <td class="pageHeading"><?php echo $page_title; ?></td>
           </tr>
         </table></td>
       </tr>
@@ -119,10 +189,10 @@ ryuhei@secondbrain.co.jp
       <tr>
         <td><table border="0" width="100%" cellspacing="2" cellpadding="2" class="knBox">
           <tr>
-            <td class="knMenu"><?php echo $siInfo->shop_info_note . tep_draw_hidden_field('shop_info_note', $siInfo->shop_info_note); ?></td>
+            <td class="knMenu"><?php echo $siInfo->shop_info_note; ?></td>
           </tr>
           <tr>
-            <td class="knMenu" align="right"><?php echo TEXT_LAST_MODIFIED . ' ' . $siInfo->last_modified; ?></td>
+            <td class="knMenu" align="right"><?php echo (($siInfo->last_modified) ? TEXT_LAST_MODIFIED . ' ' . $siInfo->last_modified : ''); ?></td>
           </tr>
         </table></td>
       </tr>
@@ -181,7 +251,13 @@ ryuhei@secondbrain.co.jp
       <tr>
         <td><table border="0" width="100%" cellspacing="0" cellpadding="2">
           <tr>
-            <td class="main" align="right"><?php echo tep_draw_hidden_field('shop_info_note', $siInfo->shop_info_note) . tep_draw_hidden_field('allow_edit_title', $siInfo->allow_edit_title) . tep_draw_hidden_field('allow_edit_value2', $siInfo->allow_edit_value2) . tep_draw_hidden_field('last_modified', $siInfo->last_modified) . tep_image_submit('button_preview.gif', IMAGE_PREVIEW) . '&nbsp;&nbsp;<a href="' . tep_href_link(FILENAME_SHOP_INFO) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>'; ?></td>
+            <td class="main" align="right">
+<?php
+        if ($siInfo->shop_info_key == 'SHOP_INFO_OPTIONAL') {
+          echo '<a href="' . tep_href_link(FILENAME_SHOP_INFO, 'action=delete_confirm&shop_info_id=' . $siID) . '">' . tep_image_button('button_delete.gif', IMAGE_DELETE) . '</a>&nbsp;&nbsp;';
+        }
+        echo tep_draw_hidden_field('shop_info_note', $siInfo->shop_info_note) . tep_draw_hidden_field('allow_edit_title', $siInfo->allow_edit_title) . tep_draw_hidden_field('allow_edit_value2', $siInfo->allow_edit_value2) . tep_draw_hidden_field('last_modified', $siInfo->last_modified) . tep_image_submit('button_preview.gif', IMAGE_PREVIEW) . '&nbsp;&nbsp;<a href="' . tep_href_link(FILENAME_SHOP_INFO) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>';
+?></td>
           </tr>
         </table></td>
       </form></tr>
@@ -189,6 +265,11 @@ ryuhei@secondbrain.co.jp
         break;
       case 'confirm':
       // ǧ
+      if ($siID) {
+        $action = 'update';
+      } else {
+        $action = 'insert';
+      }
 ?>
     <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
       <tr>
@@ -207,7 +288,7 @@ ryuhei@secondbrain.co.jp
       <tr>
         <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
       </tr>
-      <tr><?php echo tep_draw_form('shop_info', FILENAME_SHOP_INFO, 'action=update') . tep_draw_hidden_field('shop_info_id', $siID); ?>
+      <tr><?php echo tep_draw_form('shop_info', FILENAME_SHOP_INFO, 'action=' . $action) . tep_draw_hidden_field('shop_info_id', $siID); ?>
         <td><table border="0" cellspacing="0" cellpadding="2">
           <tr>
             <td class="main"><b>
@@ -267,6 +348,86 @@ ryuhei@secondbrain.co.jp
           </tr>
         </table></td>
       </form></tr>
+<?php
+        break;
+      case 'delete_confirm':
+      // γǧ
+?>
+    <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="2">
+      <tr>
+        <td><table border="0" width="100%" cellspacing="0" cellpadding="0">
+          <tr>
+            <td class="pageHeading"><?php echo TEXT_DELETE_SHOP_INFO_CONFIRM; ?></td>
+          </tr>
+        </table></td>
+      </tr>
+      <tr>
+        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
+      </tr>
+      <tr>
+        <td><?php echo TEXT_DELETE_CONFIRM_NOTE; ?></td>
+      </tr>
+      <tr>
+        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
+      </tr>
+      <tr><?php echo tep_draw_form('shop_info', FILENAME_SHOP_INFO, 'action=delete') . tep_draw_hidden_field('shop_info_id', $siID); ?>
+        <td><table border="0" cellspacing="0" cellpadding="2">
+          <tr>
+            <td class="main"><b>
+<?php
+         if ($siInfo->allow_tags) {
+           echo  $siInfo->shop_info_title;
+         } else {
+           echo nl2br(htmlspecialchars($siInfo->shop_info_title));
+         }
+?></b></td>
+          </tr>
+          <tr>
+            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
+          </tr>
+          <tr>
+            <td class="main">
+<?php
+         if ($siInfo->allow_tags) {
+           echo  $siInfo->shop_info_value;
+         } else {
+           echo nl2br(htmlspecialchars($siInfo->shop_info_value));
+         }
+?>
+            </td>
+          </tr>
+<?php
+         if ($siInfo->allow_edit_value2) {
+?>
+          <tr>
+            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
+          </tr>
+          <tr>
+            <td class="main">
+<?php
+         if ($siInfo->allow_tags) {
+           echo $siInfo->shop_info_value2;
+         } else {
+           echo nl2br(htmlspecialchars($siInfo->shop_info_value2));
+         }
+?>
+            </td>
+          </tr>
+<?php
+         }
+?>
+        </table></td>
+      </tr>
+      <tr>
+        <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
+      </tr>
+      <tr>
+        <td><table border="0" width="100%" cellspacing="0" cellpadding="2">
+          <tr>
+            <td class="main" align="right"><?php echo tep_image_submit('button_delete.gif', IMAGE_DELETE) . ' <a href="' . tep_href_link(FILENAME_SHOP_INFO) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>'; ?></td>
+          </tr>
+        </table></td>
+      </form></tr>
 <?php
     }
   } else {
@@ -282,8 +443,13 @@ ryuhei@secondbrain.co.jp
       </tr>
       <tr>
         <td align="center"><table border="0" width="100%" cellspacing="0" cellpadding="0" class="knBox">
+        <tr><td colspan="2"><?php echo tep_draw_separator('pixel_trans.gif', '1', '5'); ?></td></tr>
+        <tr><td width="50%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="0">
           <tr>
-            <td colspan="2"><?php echo tep_draw_separator('pixel_trans.gif', '1', '5'); ?></td>
+            <td colspan="2"><?php echo TEXT_STANDING_SHOP_INFO; ?></td>
+          </tr>
+          <tr>
+            <td colspan="2"><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
           </tr>
 <?php
     while($shop_info = tep_db_fetch_array($shop_info_query)) {
@@ -294,12 +460,42 @@ ryuhei@secondbrain.co.jp
             <td class="knMenu"><?php echo $siInfo->shop_info_note; ?></td>
           </tr>
           <tr>
-            <td><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
+            <td colspan="2"><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
           </tr>
 <?php
     }
 ?>
         </table></td>
+        <td width="50%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="0">
+          <tr>
+            <td colspan="2"><?php echo TEXT_OPTIONAL_SHOP_INFO; ?></td>
+          </tr>
+          <tr>
+            <td colspan="2"><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
+          </tr>
+<?php
+    while($shop_info2 = tep_db_fetch_array($shop_info2_query)) {
+      $siInfo2 = new objectInfo($shop_info2);
+?>
+          <tr>
+            <td valign="top"><?php echo '<a href="' . tep_href_link(FILENAME_SHOP_INFO, 'action=edit_value&siID=' . $siInfo2->shop_info_id) . '" class="knMenu"><b>' . $siInfo2->shop_info_title . '</b></a>'; ?></td>
+            <td class="knMenu"><?php echo $siInfo2->shop_info_note; ?></td>
+          </tr>
+          <tr>
+            <td colspan="2"><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
+          </tr>
+<?php
+    }
+?>
+          <tr>
+            <td valign="top">&nbsp;</td>
+            <td class="knMenu"><?php echo '<a href="' . tep_href_link(FILENAME_SHOP_INFO, 'action=add_value') . '" class="knMenu">' . tep_image_button('button_insert.gif', IMAGE_INSERT) . '</a>'; ?></td>
+          </tr>
+          <tr>
+            <td colspan="2"><?php echo tep_draw_separator('pixel_trans.gif', '1', '10'); ?></td>
+          </tr>
+        </table></td></tr>
+        </table></td>
       </tr>
 <?php
   }
