@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: checkout_payment_address.php,v 1.5 2006/08/07 06:21:15 ryu Exp $
+  $Id: checkout_payment_address.php,v 1.8 2007/06/12 06:02:03 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -147,7 +147,7 @@
       }
 
       if ($error == false) {
-        $next_id_query = tep_db_query("select max(address_book_id) as address_book_id from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . $customer_id . "'");
+        $next_id_query = tep_db_query("select max(address_book_id) as address_book_id from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . (int)$customer_id . "'");
         if (tep_db_num_rows($next_id_query)) {
           $next_id = tep_db_fetch_array($next_id_query);
           $entry_id = $next_id['address_book_id']+1;
@@ -204,7 +204,7 @@
 
       $billto = $HTTP_POST_VARS['address'];
 
-      $check_address_query = tep_db_query("select count(*) as total from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . $customer_id . "' and address_book_id = '" . $billto . "'");
+      $check_address_query = tep_db_query("select count(*) as total from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . (int)$customer_id . "' and address_book_id = '" . (int)$billto . "'");
       $check_address = tep_db_fetch_array($check_address_query);
 
       if ($check_address['total'] == '1') {
@@ -356,6 +356,7 @@ function check_form() {
 //--></script>
 </head>
 <body>
+<div id="container">
 <!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
 <!-- /header -->
@@ -371,21 +372,7 @@ function check_form() {
 <!-- /right_contents -->
 <hr />
 <!-- main_contents -->
-<?php
-  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsRL">' . "\n";
-    } else {
-      echo '<div id="mainContentsR">' . "\n";
-    }
-  } else {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsL">' . "\n";
-    } else {
-      echo '<div id="mainContents">' . "\n";
-    }
-  }
-?>
+<div id="mainContents">
 <p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
 <h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
 <?php echo tep_draw_form('checkout_address', tep_href_link(FILENAME_CHECKOUT_PAYMENT_ADDRESS, '', 'SSL'), 'post', 'onSubmit="return check_form();"') . "\n"; ?>
@@ -404,7 +391,7 @@ function check_form() {
 <p><?php echo TEXT_SELECTED_PAYMENT_DESTINATION; ?></p>
 <p class="addressLabel"><?php echo tep_address_label($customer_id, $billto, true, ' ', '<br />'); ?></p>
 <?php
-    $addresses_count_query = tep_db_query("select count(*) as total from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . $customer_id . "' and address_book_id != '" . $billto . "'");
+    $addresses_count_query = tep_db_query("select count(*) as total from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . (int)$customer_id . "' and address_book_id != '" . (int)$billto . "'");
     $addresses_count = tep_db_fetch_array($addresses_count_query);
 
     if ($addresses_count['total'] > 0) {
@@ -416,7 +403,7 @@ function check_form() {
       $radio_buttons = 0;
 
 // 2003-06-06 add_telephone
-      $addresses_query = tep_db_query("select address_book_id, entry_firstname as firstname, entry_lastname as lastname, entry_company as company, entry_street_address as street_address, entry_suburb as suburb, entry_city as city, entry_postcode as postcode, entry_state as state, entry_zone_id as zone_id, entry_country_id as country_id, entry_telephone as telephone from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . $customer_id . "'");
+      $addresses_query = tep_db_query("select address_book_id, entry_firstname as firstname, entry_lastname as lastname, entry_company as company, entry_street_address as street_address, entry_suburb as suburb, entry_city as city, entry_postcode as postcode, entry_state as state, entry_zone_id as zone_id, entry_country_id as country_id, entry_telephone as telephone from " . TABLE_ADDRESS_BOOK . " where customers_id = '" . (int)$customer_id . "'");
       while ($addresses = tep_db_fetch_array($addresses_query)) {
         $format_id = tep_get_address_format_id($addresses['country_id']);
        if ($addresses['address_book_id'] == $billto) {
@@ -426,7 +413,7 @@ function check_form() {
         }
 ?>
 <th class="select"><?php echo tep_draw_radio_field('address', $addresses['address_book_id'], ($addresses['address_book_id'] == $billto)); ?></th>
-<th class="title"><?php echo tep_output_string_protected(tep_get_fullname($addresses['firstname'],$addresses['lastname'])); ?></th>
+<th class="title"><?php echo tep_output_string_protected(tep_get_fullname($addresses['firstname'],$addresses['lastname'])) . TEXT_HONORIFIC; ?></th>
 </tr>
 <tr>
 <td class="select">&nbsp;</td>
@@ -464,7 +451,7 @@ function check_form() {
 <ul id="checkoutBar">
 <li class="from"><p><?php echo '<a href="' . tep_href_link(FILENAME_CHECKOUT_SHIPPING, '', 'SSL') . '">' . CHECKOUT_BAR_DELIVERY . '</a>'; ?></p></li>
 <li class="current">
-<p><?php echo tep_image(DIR_WS_IMAGES . 'checkout_bullet.gif'); ?></p>
+<?php echo tep_image(DIR_WS_IMAGES . 'checkout_bullet.gif'); ?>
 <p><?php echo CHECKOUT_BAR_PAYMENT; ?></p>
 </li>
 <li class="to"><p><?php echo CHECKOUT_BAR_CONFIRMATION; ?></p></li>
@@ -474,12 +461,13 @@ function check_form() {
 </form>
 </div>
 <!-- /main_contents -->
+</div>
+<!-- /contents -->
 <hr />
 <!-- footer -->
 <?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
 <!-- /footer -->
 </div>
-<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
