@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: create_account.php,v 1.6 2006/08/07 06:21:15 ryu Exp $
+  $Id: create_account.php,v 1.7 2007/06/12 06:02:03 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -35,6 +35,7 @@
 <?php require('includes/form_check.js.php'); ?>
 </head>
 <body>
+<div id="container">
 <!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
 <!-- /header -->
@@ -50,21 +51,7 @@
 <!-- /right_contents -->
 <hr />
 <!-- main_contents -->
-<?php
-  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsRL">' . "\n";
-    } else {
-      echo '<div id="mainContentsR">' . "\n";
-    }
-  } else {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsL">' . "\n";
-    } else {
-      echo '<div id="mainContents">' . "\n";
-    }
-  }
-?>
+<div id="mainContents">
 <p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
 <h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
 <?php echo tep_draw_form('account_edit', tep_href_link(FILENAME_CREATE_ACCOUNT_PROCESS, '', 'SSL'), 'post', 'onSubmit="return check_form();"') . tep_draw_hidden_field('action', 'process') . "\n"; ?>
@@ -91,12 +78,13 @@
 </form>
 </div>
 <!-- /main_contents -->
+</div>
+<!-- /contents -->
 <hr />
 <!-- footer -->
 <?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
 <!-- /footer -->
 </div>
-<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
