@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: geta_search_result.php,v 1.4 2006/08/07 06:21:15 ryu Exp $
+  $Id: geta_search_result.php,v 1.5 2007/06/12 06:02:03 ryu Exp $
 
 Koshoten.net2
 http://www.koshoten.net/
@@ -94,6 +94,7 @@ http://www.koshoten.net/
 <link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_GETA_SEARCH_RESULT, 0, strrpos(FILENAME_GETA_SEARCH_RESULT, '.'));?>.css" media="screen,print" />
 </head>
 <body>
+<div id="container">
 <!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
 <!-- /header -->
@@ -109,24 +110,10 @@ http://www.koshoten.net/
 <!-- /right_contents -->
 <hr />
 <!-- main_contents -->
-<?php
-  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsRL">' . "\n";
-    } else {
-      echo '<div id="mainContentsR">' . "\n";
-    }
-  } else {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsL">' . "\n";
-    } else {
-      echo '<div id="mainContents">' . "\n";
-    }
-  }
-?>
+<div id="mainContents">
 <p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
 <h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
-<div id="advancedSearch">
+<div id="getaSearch">
 <?php echo tep_draw_form('geta_search', tep_href_link(FILENAME_GETA_SEARCH_RESULT, '', 'NONSSL', false)) . "\n"; ?>
 <p><?php echo tep_draw_textarea_field('search_text', 'soft', '', '5'); ?></p>
 <p class="buttonArea"><?php echo '<input type="submit" value="' . BOX_GETA_SEARCH_SUBMIT . '" /><input type="reset" value="' . BOX_GETA_SEARCH_RESET . '" />'; ?></p>
@@ -135,7 +122,7 @@ http://www.koshoten.net/
   if (!$no_results) {
     echo '<p>' . sprintf(TEXT_RESULTS_COUNT, $start, $start + $results_count - 1) . '</p>' . "\n";
     
-    echo '<table>' . "\n";
+    echo '<table class="listBox">' . "\n";
     for ($i=0, $n=sizeof($s_result_products); $i<$n; $i++) {
       if (($s_result_products[$i]['list_num']/2) == floor($s_result_products[$i]['list_num']/2)) {
         $geta_row_style = 'even';
@@ -187,12 +174,13 @@ http://www.koshoten.net/
 </div>
 </div>
 <!-- /main_contents -->
+</div>
+<!-- /contents -->
 <hr />
 <!-- footer -->
 <?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
 <!-- /footer -->
 </div>
-<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
