@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: geta_themes.php,v 1.4 2006/08/07 06:21:15 ryu Exp $
+  $Id: geta_themes.php,v 1.5 2007/06/12 06:02:03 ryu Exp $
 
 Koshoten.net2
 http://www.koshoten.net/
@@ -116,6 +116,7 @@ http://www.koshoten.net/
 <link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_GETA_THEMES, 0, strrpos(FILENAME_GETA_THEMES, '.'));?>.css" media="screen,print" />
 </head>
 <body>
+<div id="container">
 <!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
 <!-- /header -->
@@ -131,21 +132,7 @@ http://www.koshoten.net/
 <!-- /right_contents -->
 <hr />
 <!-- main_contents -->
-<?php
-  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsRL">' . "\n";
-    } else {
-      echo '<div id="mainContentsR">' . "\n";
-    }
-  } else {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsL">' . "\n";
-    } else {
-      echo '<div id="mainContents">' . "\n";
-    }
-  }
-?>
+<div id="mainContents">
 <p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
 <?php
   switch ($action) {
@@ -189,7 +176,7 @@ http://www.koshoten.net/
       if (!$no_results) {
         echo '<p>' . sprintf(TEXT_RESULTS_COUNT, $start, $start + $results_count - 1) . '</p>' . "\n";
 
-        echo '<table>' . "\n";
+        echo '<table class="listBox">' . "\n";
         for ($i=0, $n=sizeof($s_result_products); $i<$n; $i++) {
           if (($s_result_products[$i]['list_num']/2) == floor($s_result_products[$i]['list_num']/2)) {
             $geta_row_style = 'even';
@@ -239,7 +226,7 @@ http://www.koshoten.net/
 <p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_GETA_THEMES) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
 </div>
 </div>
-<?php 
+<?php
       break;
     case 'themes_list':
       // ơް
@@ -249,7 +236,7 @@ http://www.koshoten.net/
 <?php
       while ($geta_themes = tep_db_fetch_array($geta_themes_query)) {
         echo '<h4><a href="' . tep_href_link(FILENAME_GETA_THEMES, 'gtID=' . $geta_themes['geta_themes_id']) . '">' . $geta_themes['geta_themes_title'] . '</a></h4>' . "\n";
-        echo '<p>' . nl2br(mb_substr($geta_themes['geta_themes_description'], 0 ,100)) . '...</p>' . "\n";
+        echo '<blockquote>' . nl2br(mb_substr($geta_themes['geta_themes_description'], 0 ,100)) . '...</blockquote>' . "\n";
       }
 ?>
 <div class="buttonLine">
@@ -275,12 +262,13 @@ http://www.koshoten.net/
 ?>
 </div>
 <!-- /main_contents -->
+</div>
+<!-- /contents -->
 <hr />
 <!-- footer -->
 <?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
 <!-- /footer -->
 </div>
-<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
