@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: reviews.php,v 1.2 2006/07/16 05:09:34 ryu Exp $
+  $Id: reviews.php,v 1.3 2007/04/16 05:40:10 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -19,7 +19,7 @@
   $infobox_header = BOX_HEADING_REVIEWS;
   $infobox_footer = '<a href="' . tep_href_link(FILENAME_REVIEWS) . '">' . BOX_MORE_REVIEWS . '</a>';
 
-  $random_select = "select r.reviews_id, r.reviews_rating, p.products_id, p.products_image, pd.products_name from " . TABLE_REVIEWS . " r, " . TABLE_REVIEWS_DESCRIPTION . " rd, " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = r.products_id and r.reviews_id = rd.reviews_id and rd.languages_id = '" . $languages_id . "' and p.products_id = pd.products_id and pd.language_id = '" . $languages_id . "'";
+  $random_select = "select r.reviews_id, r.reviews_rating, p.products_id, p.products_image, pd.products_name from " . TABLE_REVIEWS . " r, " . TABLE_REVIEWS_DESCRIPTION . " rd, " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = r.products_id and r.reviews_id = rd.reviews_id and rd.languages_id = '" . (int)$languages_id . "' and p.products_id = pd.products_id and pd.language_id = '" . (int)$languages_id . "'";
   if (isset($HTTP_GET_VARS['products_id'])) {
     $random_select .= " and p.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "'";
   }
@@ -29,7 +29,7 @@
   $box_reviews_contents = '';
   if ($random_product) {
 // display random review box
-    $review_query = tep_db_query("select substring(reviews_text, 1, 60) as reviews_text from " . TABLE_REVIEWS_DESCRIPTION . " where reviews_id = '" . $random_product['reviews_id'] . "' and languages_id = '" . $languages_id . "'");
+    $review_query = tep_db_query("select substring(reviews_text, 1, 60) as reviews_text from " . TABLE_REVIEWS_DESCRIPTION . " where reviews_id = '" . $random_product['reviews_id'] . "' and languages_id = '" . (int)$languages_id . "'");
     $review = tep_db_fetch_array($review_query);
 
     $review = htmlspecialchars($review['reviews_text']);
