@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: general.php,v 1.2 2006/07/16 05:09:34 ryu Exp $
+  $Id: general.php,v 1.4 2007/04/16 07:57:08 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -445,6 +445,7 @@
     $statename = tep_get_zone_name($country_id,$zone_id,$state); // for Japanese Localize
 // 2003-06-06 add_telephone
     $telephone = tep_output_string_protected($address['telephone']);
+    $honorific = TEXT_HONORIFIC;
 
     if ($html) {
 // HTML Mode
@@ -959,7 +960,7 @@
   function tep_get_prid($uprid) {
     $pieces = split('[{]', $uprid, 2);
 
-    return $pieces[0];
+    return (int)$pieces[0];
   }
 
 ////
