@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: japanese.php,v 1.6 2006/07/16 05:09:34 ryu Exp $
+  $Id: japanese.php,v 1.9 2007/05/08 03:13:55 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -97,7 +97,7 @@ define('BOX_GETA_SEARCH_TEXT', '<small>ɡʸϤ鸡</small>');
 define('BOX_GETA_SEARCH_TEXT2', 'ɡʸϤϤƤ');
 define('BOX_GETA_SEARCH_SUBMIT', 'Ϣ۸');
 define('BOX_GETA_SEARCH_RESET', 'ꥢ');
-define('BOX_MORE_GETA_THEMES', 'äȡ');
+define('BOX_MORE_GETA_THEMES', 'ä...');
 
 // categories box text in includes/boxes/categories.php
 define('BOX_HEADING_CATEGORIES', 'ƥ꡼');
@@ -324,7 +324,7 @@ define('ICON_ARROW_RIGHT', 'ɽ'); //more
 define('ICON_CART', 'Ȥ');
 define('ICON_WARNING', 'ٹ');
 
-define('TEXT_GREETING_PERSONAL', 'ä㤤ޤ<span class="greetUser">%s </span> <a href="%s">徦</a> ˤʤޤ');
+define('TEXT_GREETING_PERSONAL', 'ä㤤ޤ<span class="greetUser">%s </span>');
 define('TEXT_GREETING_GUEST', '<span class="greetUser">Ȥ</span>ä㤤ޤ <a href="%s"></a>ޤ Ȥ⡢<a href="%s"></a>ޤ');
 
 define('TEXT_SORT_PRODUCTS', 'ʤ¤ؤ ');
@@ -343,6 +343,7 @@ define('TEXT_NO_NEW_PRODUCTS', '߾ʤϿƤޤ...');
 define('TEXT_UNKNOWN_TAX_RATE', 'Ψ');
 
 define('TEXT_REQUIRED', 'ɬ');
+define('TEXT_HONORIFIC', ' ');
 
 define('TEXT_TIME_SPECIFY', 'Ϥ: '); // add for Japanese update
 
