@@ -45,7 +45,7 @@ define('TABLE_HEADING_DESCRIPTION', '');
 define('TEXT_NO_PRODUCTS', 'Υƥ꡼ξʤϤޤ...');
 define('TEXT_NO_PRODUCTS2', '' . KN_CFG_USE_MANUFACTURERS . 'ξʤϤޤ...');
 define('TEXT_NUMBER_OF_PRODUCTS', '߸˿: ');
-define('TEXT_SHOW', '<b>ʹ:</b> ');
+define('TEXT_SHOW', '<strong>ʹ:</strong> ');
 define('TEXT_BUY', ' ');
 define('TEXT_NOW', ' ');	
 define('TEXT_ALL', '');
