@@ -17,5 +17,5 @@ define('MODULE_SHIPPING_SASSI_TEXT_WAY', 'Ҿ');
 define('MODULE_SHIPPING_SASSI_TEXT_WEIGHT', '');
 define('MODULE_SHIPPING_SASSI_TEXT_AMOUNT', '');
 
-define('MODULE_SHIPPING_SASSI_TEXT_GET_QUOTE_LATER', '  <font color=red>ϼ˻</font>');
+define('MODULE_SHIPPING_SASSI_TEXT_GET_QUOTE_LATER', '  <span class="calcLater">ϼ˻</span>');
 ?>
