@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: order_details.php,v 1.2 2006/07/16 05:09:36 ryu Exp $
+  $Id: order_details.php,v 1.3 2007/06/12 06:02:10 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -42,26 +42,26 @@
 
 // Delete box only for shopping cart
     if (strstr($PHP_SELF, FILENAME_SHOPPING_CART)) {
-      echo '<td class="remove"><p>' . tep_draw_checkbox_field('cart_delete[]', $products[$i]['id']) . '</p></td>' . "\n";
+      echo '<td class="remove">' . tep_draw_checkbox_field('cart_delete[]', $products[$i]['id']) . '</td>' . "\n";
     }
 
 // Quantity box or information as an input box or text
     if (strstr($PHP_SELF, FILENAME_SHOPPING_CART)) {
-      echo '<td class="quantity"><p>' . tep_draw_input_field('cart_quantity[]', $products[$i]['quantity'], 'size="4"') . tep_draw_hidden_field('products_id[]', $products[$i]['id']) . '</p></td>' . "\n";
+      echo '<td class="quantity">' . tep_draw_input_field('cart_quantity[]', $products[$i]['quantity'], 'size="4"') . tep_draw_hidden_field('products_id[]', $products[$i]['id']) . '</td>' . "\n";
     } else {
-      echo '<td class="quantity"><p>' . $products[$i]['quantity'] . '</p></td>' . "\n";
+      echo '<td class="quantity">' . $products[$i]['quantity'] . '</td>' . "\n";
     }
 
 // Model
     if ((KN_CFG_PRODUCT_LIST_MODEL > 0) && strstr($PHP_SELF, FILENAME_SHOPPING_CART)) {
-      echo '<td class="model"><p><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $products[$i]['id']) . '">' . $products[$i]['model'] . '</a></p></td>' . "\n";
+      echo '<td class="model"><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $products[$i]['id']) . '">' . $products[$i]['model'] . '</a></td>' . "\n";
     }
   
 // Product name, with or without link
     if (strstr($PHP_SELF, FILENAME_SHOPPING_CART)) {
-      echo '<td class="product"><p><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $products[$i]['id']) . '">' . $products[$i]['name'] . '</a>';
+      echo '<td class="product"><a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $products[$i]['id']) . '">' . $products[$i]['name'] . '</a>';
     } else {
-      echo '<td class="product"><p>' . $products[$i]['name'] . '';
+      echo '<td class="product">' . $products[$i]['name'] . '';
     }
 
 // Display marker if stock quantity insufficient
@@ -82,18 +82,18 @@
       }
     }
 
-    echo '</p></td>' . "\n";
+    echo '</td>' . "\n";
 
 // Tax (not in shopping cart, tax rate may be unknown)
     if (!strstr($PHP_SELF, FILENAME_SHOPPING_CART)) {
-      echo '<td class="tax"><p>' . number_format($products[$i]['tax'], TAX_DECIMAL_PLACES) . '%</p></td>' . "\n";
+      echo '<td class="tax">' . number_format($products[$i]['tax'], TAX_DECIMAL_PLACES) . '%</td>' . "\n";
     }
 
 // Product price  
     if (!strstr($PHP_SELF, FILENAME_ACCOUNT_HISTORY_INFO)) {
-      echo '<td class="price"><p>' . $currencies->display_price($products[$i]['price'], tep_get_tax_rate($products[$i]['tax_class_id']), $products[$i]['quantity']);
+      echo '<td class="price">' . $currencies->display_price($products[$i]['price'], tep_get_tax_rate($products[$i]['tax_class_id']), $products[$i]['quantity']);
     } else {
-      echo '<td class="price"><p>' . $currencies->display_price($products[$i]['price'], $products[$i]['tax'], $products[$i]['quantity']);
+      echo '<td class="price">' . $currencies->display_price($products[$i]['price'], $products[$i]['tax'], $products[$i]['quantity']);
     }
 
 // Product options prices
@@ -113,7 +113,7 @@
       }
     }
 
-    echo '</p></td>' . "\n" .
+    echo '</td>' . "\n" .
            '</tr>' . "\n";
   }
   echo '</table>' . "\n";
