@@ -37,6 +37,7 @@ ryuhei@secondbrain.co.jp
 <link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_INFORMATION, 0, strrpos(FILENAME_INFORMATION, '.'));?>.css" media="screen,print" />
 </head>
 <body>
+<div id="container">
 <!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
 <!-- /header -->
@@ -52,21 +53,7 @@ ryuhei@secondbrain.co.jp
 <!-- /right_contents -->
 <hr />
 <!-- main_contents -->
-<?php
-  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsRL">' . "\n";
-    } else {
-      echo '<div id="mainContentsR">' . "\n";
-    }
-  } else {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsL">' . "\n";
-    } else {
-      echo '<div id="mainContents">' . "\n";
-    }
-  }
-?>
+<div id="mainContents">
 <p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
 <h2 class="pageHeading"><?php echo $shop_info['shop_info_title']; ?></h2>
 <div id="shopInfo">
@@ -75,13 +62,15 @@ ryuhei@secondbrain.co.jp
 <p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_DEFAULT) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
 </div>
 </div>
+</div>
 <!-- /main_contents -->
+</div>
+<!-- /contents -->
 <hr />
 <!-- footer -->
 <?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
 <!-- /footer -->
 </div>
-<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
