@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: reviews.php,v 1.4 2006/08/07 06:21:15 ryu Exp $
+  $Id: reviews.php,v 1.6 2007/06/12 06:02:03 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -30,6 +30,7 @@
 <link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_REVIEWS, 0, strrpos(FILENAME_REVIEWS, '.'));?>.css" media="screen,print" />
 </head>
 <body>
+<div id="container">
 <!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
 <!-- /header -->
@@ -45,26 +46,12 @@
 <!-- /right_contents -->
 <hr />
 <!-- main_contents -->
-<?php
-  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsRL">' . "\n";
-    } else {
-      echo '<div id="mainContentsR">' . "\n";
-    }
-  } else {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsL">' . "\n";
-    } else {
-      echo '<div id="mainContents">' . "\n";
-    }
-  }
-?>
+<div id="mainContents">
 <p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
 <h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
 <div id="reviews">
 <?php
-  $reviews_query_raw = "select r.reviews_id, rd.reviews_text, r.reviews_rating, r.date_added, p.products_id, pd.products_name, p.products_image, r.customers_name from " . TABLE_REVIEWS . " r, " . TABLE_REVIEWS_DESCRIPTION . " rd, " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = r.products_id and r.reviews_id = rd.reviews_id and p.products_id = pd.products_id and pd.language_id = '" . $languages_id . "' and rd.languages_id = '" . $languages_id . "' order by r.reviews_id DESC";
+  $reviews_query_raw = "select r.reviews_id, rd.reviews_text, r.reviews_rating, r.date_added, p.products_id, pd.products_name, p.products_image, r.customers_name from " . TABLE_REVIEWS . " r, " . TABLE_REVIEWS_DESCRIPTION . " rd, " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = r.products_id and r.reviews_id = rd.reviews_id and p.products_id = pd.products_id and pd.language_id = '" . (int)$languages_id . "' and rd.languages_id = '" . (int)$languages_id . "' order by r.reviews_id DESC";
   $reviews_split = new splitPageResults($HTTP_GET_VARS['page'], MAX_DISPLAY_NEW_REVIEWS, $reviews_query_raw, $reviews_numrows);
   $reviews_query = tep_db_query($reviews_query_raw);
   while ($reviews = tep_db_fetch_array($reviews_query)) {
@@ -85,12 +72,13 @@
 </div>
 </div>
 <!-- /main_contents -->
+</div>
+<!-- /contents -->
 <hr />
 <!-- footer -->
 <?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
 <!-- /footer -->
 </div>
-<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
