@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: tell_a_friend.php,v 1.4 2006/08/07 06:21:15 ryu Exp $
+  $Id: tell_a_friend.php,v 1.6 2007/06/12 06:02:03 ryu Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -16,7 +16,7 @@
   require('includes/application_top.php');
 
   if (tep_session_is_registered('customer_id')) {
-    $account = tep_db_query("select customers_firstname, customers_lastname, customers_email_address from " . TABLE_CUSTOMERS . " where customers_id = '" . $customer_id . "'");
+    $account = tep_db_query("select customers_firstname, customers_lastname, customers_email_address from " . TABLE_CUSTOMERS . " where customers_id = '" . (int)$customer_id . "'");
     $account_values = tep_db_fetch_array($account);
   } elseif (ALLOW_GUEST_TO_TELL_A_FRIEND == 'false') {
     $navigation->set_snapshot();
@@ -25,7 +25,7 @@
 
   $valid_product = false;
   if (isset($HTTP_GET_VARS['products_id'])) {
-    $product_info_query = tep_db_query("select pd.products_name from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and p.products_id = pd.products_id and pd.language_id = '" . $languages_id . "'");
+    $product_info_query = tep_db_query("select pd.products_name from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where p.products_status = '1' and p.products_id = '" . (int)$HTTP_GET_VARS['products_id'] . "' and p.products_id = pd.products_id and pd.language_id = '" . (int)$languages_id . "'");
     $valid_product = (tep_db_num_rows($product_info_query) > 0);
   }
 
@@ -44,6 +44,7 @@
 <link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_TELL_A_FRIEND, 0, strrpos(FILENAME_TELL_A_FRIEND, '.'));?>.css" media="screen,print" />
 </head>
 <body>
+<div id="container">
 <!-- header -->
 <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
 <!-- /header -->
@@ -59,21 +60,7 @@
 <!-- /right_contents -->
 <hr />
 <!-- main_contents -->
-<?php
-  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsRL">' . "\n";
-    } else {
-      echo '<div id="mainContentsR">' . "\n";
-    }
-  } else {
-    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
-      echo '<div id="mainContentsL">' . "\n";
-    } else {
-      echo '<div id="mainContents">' . "\n";
-    }
-  }
-?>
+<div id="mainContents">
 <p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
 <?php
   if ($valid_product == false) {
@@ -186,7 +173,11 @@
 </tr>
 </table>
 <h3><?php echo FORM_TITLE_FRIEND_MESSAGE; ?></h3>
-<p><?php echo tep_draw_textarea_field('yourmessage', 'soft', 40, 8);?></p>
+<table>
+<tr>
+<td><?php echo tep_draw_textarea_field('yourmessage', 'soft', 40, 8);?></td>
+</tr>
+</table>
 <div class="buttonLine">
 <p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $HTTP_GET_VARS['products_id']) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
 <p class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
@@ -199,12 +190,13 @@
 ?>
 </div>
 <!-- /main_contents -->
+</div>
+<!-- /contents -->
 <hr />
 <!-- footer -->
 <?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
 <!-- /footer -->
 </div>
-<!-- /contents -->
 </body>
 </html>
 <?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
